@@ -7,14 +7,14 @@
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of 
+ *  published by the Free Software Foundation; either version 2 of
  *  the License, or (at your option) any later version.
- *   
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *   
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -26,6 +26,7 @@
 #include <qtimer.h>
 #include "SolarWinds.h"
 #include "SolarWinds.moc"
+#include <GL/glu.h>
 
 
 #define NUMCONSTS   9
@@ -594,7 +595,7 @@ class KSolarWindsSaverInterface : public KScreenSaverInterface
 
 public:
     virtual KAboutData* aboutData() {
-        return new KAboutData( "ksolarwinds.kss", 0, ki18n( "Solar Winds" ), "1.0", ki18n( "Solar Winds" ) );
+        return new KAboutData( "ksolarwinds.kss", "klock", ki18n( "Solar Winds" ), "1.0", ki18n( "Solar Winds" ) );
     }
 
 
@@ -689,16 +690,17 @@ static const char* defaultText[] =
 
 
 KSWindsSetup::KSWindsSetup( QWidget* parent )
-        : KDialog( parent)
+    : KDialog( parent)
 {
     setButtonText( Help, i18n( "A&bout" ) );
-	setButtons(Ok|Cancel|Help);
-	setDefaultButton(Ok);
-	setCaption(i18n( "Setup Solar Wind" ));
-	setModal(true);
-	showButtonSeparator(true);
+    setButtons(Ok|Cancel|Help);
+    setDefaultButton(Ok);
+    setCaption(i18n( "Setup Solar Wind" ));
+    setModal(true);
+    showButtonSeparator(true);
+    setButtonText( Help, i18n( "A&bout" ) );
     QWidget *main = new QWidget(this);
-	setMainWidget(main);
+    setMainWidget(main);
 
     QHBoxLayout* top = new QHBoxLayout( main );
     top->setSpacing( spacingHint() );
@@ -725,6 +727,7 @@ KSWindsSetup::KSWindsSetup( QWidget* parent )
         QPalette palette;
         palette.setColor( preview->backgroundRole(), Qt::black );
         preview->setPalette( palette );
+	preview->setAutoFillBackground(true);
     }
     preview->show();    // otherwise saver does not get correct size
     _saver = new KSWindsScreenSaver( preview->winId() );
@@ -733,8 +736,8 @@ KSWindsSetup::KSWindsSetup( QWidget* parent )
     // Now that we have _saver...
     modeW->setCurrentIndex( _saver->mode() );    // set before we connect
     connect( modeW, SIGNAL(activated(int)), _saver, SLOT(setMode(int)) );
-	connect( this, SIGNAL(okClicked()), this, SLOT(slotOk()));
-	connect( this, SIGNAL(helpClicked()),this,SLOT(slotHelp()));
+    connect( this, SIGNAL(okClicked()), this, SLOT(slotOk()));
+    connect( this, SIGNAL(helpClicked()),this,SLOT(slotHelp()));
 }
 
 
